<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyJustifikasiRequest;
use App\Http\Requests\StoreJustifikasiRequest;
use App\Http\Requests\UpdateJustifikasiRequest;
use App\Models\Justifikasi;
use App\Models\RabOnline;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class JustifikasiController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('justifikasi_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $justifikasis = Justifikasi::with(['nama_kegiatan'])->get();

        return view('admin.justifikasis.index', compact('justifikasis'));
    }

    public function create()
    {
        abort_if(Gate::denies('justifikasi_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nama_kegiatans = RabOnline::pluck('judul_kegiatan', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.justifikasis.create', compact('nama_kegiatans'));
    }

    public function store(StoreJustifikasiRequest $request)
    {
        $justifikasi = Justifikasi::create($request->all());

        return redirect()->route('admin.justifikasis.index');
    }

    public function edit(Justifikasi $justifikasi)
    {
        abort_if(Gate::denies('justifikasi_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $nama_kegiatans = RabOnline::pluck('judul_kegiatan', 'id')->prepend(trans('global.pleaseSelect'), '');

        $justifikasi->load('nama_kegiatan');

        return view('admin.justifikasis.edit', compact('nama_kegiatans', 'justifikasi'));
    }

    public function update(UpdateJustifikasiRequest $request, Justifikasi $justifikasi)
    {
        $justifikasi->update($request->all());

        return redirect()->route('admin.justifikasis.index');
    }

    public function show(Justifikasi $justifikasi)
    {
        abort_if(Gate::denies('justifikasi_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $justifikasi->load('nama_kegiatan');

        return view('admin.justifikasis.show', compact('justifikasi'));
    }

    public function destroy(Justifikasi $justifikasi)
    {
        abort_if(Gate::denies('justifikasi_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $justifikasi->delete();

        return back();
    }

    public function massDestroy(MassDestroyJustifikasiRequest $request)
    {
        Justifikasi::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
