<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyMasterBebanRequest;
use App\Http\Requests\StoreMasterBebanRequest;
use App\Http\Requests\UpdateMasterBebanRequest;
use App\Models\MasterBeban;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class MasterBebanController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('master_beban_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $masterBebans = MasterBeban::all();

        return view('admin.masterBebans.index', compact('masterBebans'));
    }

    public function create()
    {
        abort_if(Gate::denies('master_beban_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.masterBebans.create');
    }

    public function store(StoreMasterBebanRequest $request)
    {
        $masterBeban = MasterBeban::create($request->all());

        return redirect()->route('admin.master-bebans.index');
    }

    public function edit(MasterBeban $masterBeban)
    {
        abort_if(Gate::denies('master_beban_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.masterBebans.edit', compact('masterBeban'));
    }

    public function update(UpdateMasterBebanRequest $request, MasterBeban $masterBeban)
    {
        $masterBeban->update($request->all());

        return redirect()->route('admin.master-bebans.index');
    }

    public function show(MasterBeban $masterBeban)
    {
        abort_if(Gate::denies('master_beban_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        return view('admin.masterBebans.show', compact('masterBeban'));
    }

    public function destroy(MasterBeban $masterBeban)
    {
        abort_if(Gate::denies('master_beban_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $masterBeban->delete();

        return back();
    }

    public function massDestroy(MassDestroyMasterBebanRequest $request)
    {
        MasterBeban::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
