<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyRabBebanRequest;
use App\Http\Requests\StoreRabBebanRequest;
use App\Http\Requests\UpdateRabBebanRequest;
use App\Models\MasterBeban;
use App\Models\RabBeban;
use App\Models\RabOnline;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class RabBebanController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('rab_beban_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rabBebans = RabBeban::with(['rab', 'satuanbeban', 'hargasatuan'])->get();

        return view('admin.rabBebans.index', compact('rabBebans'));
    }

    public function create()
    {
        abort_if(Gate::denies('rab_beban_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rabs = RabOnline::pluck('judul_kegiatan', 'id')->prepend(trans('global.pleaseSelect'), '');

        $satuanbebans = MasterBeban::pluck('satuan', 'id')->prepend(trans('global.pleaseSelect'), '');

        $hargasatuans = MasterBeban::pluck('harga_satuan', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.rabBebans.create', compact('rabs', 'satuanbebans', 'hargasatuans'));
    }

    public function store(StoreRabBebanRequest $request)
    {
        $rabBeban = RabBeban::create($request->all());

        return redirect()->route('admin.rab-bebans.index');
    }

    public function edit(RabBeban $rabBeban)
    {
        abort_if(Gate::denies('rab_beban_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rabs = RabOnline::pluck('judul_kegiatan', 'id')->prepend(trans('global.pleaseSelect'), '');

        $satuanbebans = MasterBeban::pluck('satuan', 'id')->prepend(trans('global.pleaseSelect'), '');

        $hargasatuans = MasterBeban::pluck('harga_satuan', 'id')->prepend(trans('global.pleaseSelect'), '');

        $rabBeban->load('rab', 'satuanbeban', 'hargasatuan');

        return view('admin.rabBebans.edit', compact('rabs', 'satuanbebans', 'hargasatuans', 'rabBeban'));
    }

    public function update(UpdateRabBebanRequest $request, RabBeban $rabBeban)
    {
        $rabBeban->update($request->all());

        return redirect()->route('admin.rab-bebans.index');
    }

    public function show(RabBeban $rabBeban)
    {
        abort_if(Gate::denies('rab_beban_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rabBeban->load('rab', 'satuanbeban', 'hargasatuan');

        return view('admin.rabBebans.show', compact('rabBeban'));
    }

    public function destroy(RabBeban $rabBeban)
    {
        abort_if(Gate::denies('rab_beban_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rabBeban->delete();

        return back();
    }

    public function massDestroy(MassDestroyRabBebanRequest $request)
    {
        RabBeban::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
