<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyRabOnlineRequest;
use App\Http\Requests\StoreRabOnlineRequest;
use App\Http\Requests\UpdateRabOnlineRequest;
use App\Models\MasterBeban;
use App\Models\RabOnline;
use App\Models\Status;
use App\Models\User;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class RabOnlineController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('rab_online_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rabOnlines = RabOnline::with(['beban', 'analyst', 'direktur', 'statues'])->get();

        return view('admin.rabOnlines.index', compact('rabOnlines'));
    }

    public function create()
    {
        abort_if(Gate::denies('rab_online_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $bebans = MasterBeban::pluck('uraian', 'id')->prepend(trans('global.pleaseSelect'), '');

        $analysts = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $direkturs = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $statues = Status::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.rabOnlines.create', compact('bebans', 'analysts', 'direkturs', 'statues'));
    }

    public function store(StoreRabOnlineRequest $request)
    {
        $rabOnline = RabOnline::create($request->all());

        return redirect()->route('admin.rab-onlines.index');
    }

    public function edit(RabOnline $rabOnline)
    {
        abort_if(Gate::denies('rab_online_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $bebans = MasterBeban::pluck('uraian', 'id')->prepend(trans('global.pleaseSelect'), '');

        $analysts = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $direkturs = User::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $statues = Status::pluck('name', 'id')->prepend(trans('global.pleaseSelect'), '');

        $rabOnline->load('beban', 'analyst', 'direktur', 'statues');

        return view('admin.rabOnlines.edit', compact('bebans', 'analysts', 'direkturs', 'statues', 'rabOnline'));
    }

    public function update(UpdateRabOnlineRequest $request, RabOnline $rabOnline)
    {
        $rabOnline->update($request->all());

        return redirect()->route('admin.rab-onlines.index');
    }

    public function show(RabOnline $rabOnline)
    {
        abort_if(Gate::denies('rab_online_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rabOnline->load('beban', 'analyst', 'direktur', 'statues');

        return view('admin.rabOnlines.show', compact('rabOnline'));
    }

    public function destroy(RabOnline $rabOnline)
    {
        abort_if(Gate::denies('rab_online_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rabOnline->delete();

        return back();
    }

    public function massDestroy(MassDestroyRabOnlineRequest $request)
    {
        RabOnline::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
