<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Http\Requests\MassDestroyRabPendapatanRequest;
use App\Http\Requests\StoreRabPendapatanRequest;
use App\Http\Requests\UpdateRabPendapatanRequest;
use App\Models\MasterBeban;
use App\Models\RabOnline;
use App\Models\RabPendapatan;
use Gate;
use Illuminate\Http\Request;
use Symfony\Component\HttpFoundation\Response;

class RabPendapatanController extends Controller
{
    public function index()
    {
        abort_if(Gate::denies('rab_pendapatan_access'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rabPendapatans = RabPendapatan::with(['rab_pendapatans', 'beban_kategori', 'beban_uraian', 'beban_satuan', 'beban_harga_satuan'])->get();

        return view('admin.rabPendapatans.index', compact('rabPendapatans'));
    }

    public function create()
    {
        abort_if(Gate::denies('rab_pendapatan_create'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rab_pendapatans = RabOnline::pluck('judul_kegiatan', 'id');

        $beban_kategoris = MasterBeban::pluck('kategori_beban', 'id')->prepend(trans('global.pleaseSelect'), '');

        $beban_uraians = MasterBeban::pluck('uraian', 'id')->prepend(trans('global.pleaseSelect'), '');

        $beban_satuans = MasterBeban::pluck('satuan', 'id')->prepend(trans('global.pleaseSelect'), '');

        $beban_harga_satuans = MasterBeban::pluck('harga_satuan', 'id')->prepend(trans('global.pleaseSelect'), '');

        return view('admin.rabPendapatans.create', compact('rab_pendapatans', 'beban_kategoris', 'beban_uraians', 'beban_satuans', 'beban_harga_satuans'));
    }

    public function store(StoreRabPendapatanRequest $request)
    {
        $rabPendapatan = RabPendapatan::create($request->all());
        $rabPendapatan->rab_pendapatans()->sync($request->input('rab_pendapatans', []));

        return redirect()->route('admin.rab-pendapatans.index');
    }

    public function edit(RabPendapatan $rabPendapatan)
    {
        abort_if(Gate::denies('rab_pendapatan_edit'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rab_pendapatans = RabOnline::pluck('judul_kegiatan', 'id');

        $beban_kategoris = MasterBeban::pluck('kategori_beban', 'id')->prepend(trans('global.pleaseSelect'), '');

        $beban_uraians = MasterBeban::pluck('uraian', 'id')->prepend(trans('global.pleaseSelect'), '');

        $beban_satuans = MasterBeban::pluck('satuan', 'id')->prepend(trans('global.pleaseSelect'), '');

        $beban_harga_satuans = MasterBeban::pluck('harga_satuan', 'id')->prepend(trans('global.pleaseSelect'), '');

        $rabPendapatan->load('rab_pendapatans', 'beban_kategori', 'beban_uraian', 'beban_satuan', 'beban_harga_satuan');

        return view('admin.rabPendapatans.edit', compact('rab_pendapatans', 'beban_kategoris', 'beban_uraians', 'beban_satuans', 'beban_harga_satuans', 'rabPendapatan'));
    }

    public function update(UpdateRabPendapatanRequest $request, RabPendapatan $rabPendapatan)
    {
        $rabPendapatan->update($request->all());
        $rabPendapatan->rab_pendapatans()->sync($request->input('rab_pendapatans', []));

        return redirect()->route('admin.rab-pendapatans.index');
    }

    public function show(RabPendapatan $rabPendapatan)
    {
        abort_if(Gate::denies('rab_pendapatan_show'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rabPendapatan->load('rab_pendapatans', 'beban_kategori', 'beban_uraian', 'beban_satuan', 'beban_harga_satuan');

        return view('admin.rabPendapatans.show', compact('rabPendapatan'));
    }

    public function destroy(RabPendapatan $rabPendapatan)
    {
        abort_if(Gate::denies('rab_pendapatan_delete'), Response::HTTP_FORBIDDEN, '403 Forbidden');

        $rabPendapatan->delete();

        return back();
    }

    public function massDestroy(MassDestroyRabPendapatanRequest $request)
    {
        RabPendapatan::whereIn('id', request('ids'))->delete();

        return response(null, Response::HTTP_NO_CONTENT);
    }
}
