<?php

namespace App\Models;

use \DateTimeInterface;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;

class RabOnline extends Model
{
    use SoftDeletes;
    use HasFactory;

    public const JENIS_KEGIATAN_SELECT = [
        '1' => 'B2C',
        '2' => 'B2B',
    ];

    public const METODE_PENYELENGGARAN_RADIO = [
        'online'  => 'online',
        'offline' => 'offline',
    ];

    public const METODE_PEMBAYARAN_SELECT = [
        'BACK TO BACK'     => 'BACK TO BACK',
        'NON BACK TO BACK' => 'NON BACK TO BACK',
    ];

    public $table = 'rab_onlines';

    protected $dates = [
        'tanggal',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    protected $fillable = [
        'judul_kl_spk_po_pks_p_8_form_pendaftaran',
        'no_kl_spk_po_pks_p_8_form_pendaftaran',
        'tgl_kl_spk_po_pks_p_8_form_pendaftaran',
        'judul_kegiatan',
        'pelanggan_user',
        'customer',
        'jumlah_peserta',
        'jumlah_hari',
        'tanggal',
        'lokasi_kota',
        'metode_penyelenggaran',
        'metode_pembayaran',
        'umur_piutang',
        'jenis_kegiatan',
        'beban_id',
        'analyst_id',
        'direktur_id',
        'statues_id',
        'created_at',
        'updated_at',
        'deleted_at',
    ];

    public function getTanggalAttribute($value)
    {
        return $value ? Carbon::parse($value)->format(config('panel.date_format')) : null;
    }

    public function setTanggalAttribute($value)
    {
        $this->attributes['tanggal'] = $value ? Carbon::createFromFormat(config('panel.date_format'), $value)->format('Y-m-d') : null;
    }

    public function beban()
    {
        return $this->belongsTo(MasterBeban::class, 'beban_id');
    }

    public function analyst()
    {
        return $this->belongsTo(User::class, 'analyst_id');
    }

    public function direktur()
    {
        return $this->belongsTo(User::class, 'direktur_id');
    }

    public function statues()
    {
        return $this->belongsTo(Status::class, 'statues_id');
    }

    protected function serializeDate(DateTimeInterface $date)
    {
        return $date->format('Y-m-d H:i:s');
    }
}
